package com.ruoyi.system.mapper;

import java.util.List;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.ruoyi.system.domain.PushMessage;

/**
 * 推送消息Mapper接口
 *
 * @author ruoyi
 * @date 2025-08-01
 */
public interface PushMessageMapper  extends BaseMapper<PushMessage>
{
    /**
     * 查询推送消息
     *
     * @param id 推送消息主键
     * @return 推送消息
     */
    public PushMessage selectPushMessageById(Long id);

    /**
     * 查询推送消息列表
     *
     * @param pushMessage 推送消息
     * @return 推送消息集合
     */
    public List<PushMessage> selectPushMessageList(PushMessage pushMessage);

    /**
     * 新增推送消息
     *
     * @param pushMessage 推送消息
     * @return 结果
     */
    public int insertPushMessage(PushMessage pushMessage);

    /**
     * 修改推送消息
     *
     * @param pushMessage 推送消息
     * @return 结果
     */
    public int updatePushMessage(PushMessage pushMessage);

    /**
     * 删除推送消息
     *
     * @param id 推送消息主键
     * @return 结果
     */
    public int deletePushMessageById(Long id);

    /**
     * 批量删除推送消息
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deletePushMessageByIds(Long[] ids);
}
